@@ -3,10 +3,7 @@
 from enum import Enum
 from bisect import bisect
 
-try:
-    from functools import cache
-except:
-    from functools import lru_cache as cache
+from functools import lru_cache as cache
 
 """ from https://unicode-table.com/en/blocks/
 """
@@ -336,7 +333,7 @@ class UnicodepointIndex(Enum):
 
 _, breakpoints, names = zip(*unicode_mapping)
 
-@cache
+@cache(maxsize=None)
 def index(c: Char) -> int:
     code = ord(c)
     i = bisect(breakpoints, code)
